==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/qnx/bardescriptoreditor.h <==
/**************************************************************************
**
** Copyright (C) 2013 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BARDESCRIPTOREDITOR_H
#define QNX_INTERNAL_BARDESCRIPTOREDITOR_H

#include <coreplugin/editormanager/ieditor.h>

QT_BEGIN_NAMESPACE
class QActionGroup;
class QToolBar;
QT_END_NAMESPACE

namespace Qnx {
namespace Internal {

class BarDescriptorDocument;
class BarDescriptorEditorWidget;

class BarDescriptorEditor : public Core::IEditor
{
    Q_OBJECT
public:
    enum EditorPage {
        General = 0,
        Application,
        Assets,
        Source
    };

    explicit BarDescriptorEditor(BarDescriptorEditorWidget *editorWidget);

    bool open(QString *errorString, const QString &fileName, const QString &realFileName);
    Core::IDocument *document();
    Core::Id id() const;
    QWidget *toolBar();

    EditorPage activePage() const;

private slots:
    void changeEditorPage(QAction *action);

private:
    void setActivePage(EditorPage page);

    BarDescriptorDocument *m_file;

    QToolBar *m_toolBar;
    QActionGroup *m_actionGroup;
};

} // namespace Internal
} // namespace Qnx

#endif // QNX_INTERNAL_BARDESCRIPTOREDITOR_H

==> qt-creator-opensource-src-3.1.0.zip: qt-creator-opensource-src-3.1.0/src/plugins/qnx/bardescriptoreditor.h <==
/**************************************************************************
**
** Copyright (C) 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BARDESCRIPTOREDITOR_H
#define QNX_INTERNAL_BARDESCRIPTOREDITOR_H

#include <coreplugin/editormanager/ieditor.h>

QT_BEGIN_NAMESPACE
class QActionGroup;
class QToolBar;
QT_END_NAMESPACE

namespace Utils { class LineColumnLabel; }

namespace Qnx {
namespace Internal {

class BarDescriptorDocument;
class BarDescriptorEditorWidget;

class BarDescriptorEditor : public Core::IEditor
{
    Q_OBJECT
public:
    enum EditorPage {
        General = 0,
        Application,
        Assets,
        Source
    };

    BarDescriptorEditor();

    bool open(QString *errorString, const QString &fileName, const QString &realFileName);
    Core::IDocument *document();
    QWidget *toolBar();

    EditorPage activePage() const;

private slots:
    void changeEditorPage(QAction *action);
    void updateCursorPosition();

private:
    void setActivePage(EditorPage page);

    BarDescriptorDocument *m_file;

    QToolBar *m_toolBar;
    QActionGroup *m_actionGroup;
    Utils::LineColumnLabel *m_cursorPositionLabel;
    QAction *m_cursorPositionAction;
};

} // namespace Internal
} // namespace Qnx

#endif // QNX_INTERNAL_BARDESCRIPTOREDITOR_H
